@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2015-2016 -- leonerd@leonerd.org.uk
 
 package Device::Chip::Adapter;
 
@@ -10,7 +10,7 @@ use warnings;
 
 use utf8;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp;
 
@@ -370,6 +370,14 @@ This includes the start condition, sending the addressing byte (which is
 implied; it should I<not> be included in C<$bytes_out>) and ending in the stop
 condition.
 
+=head2 read
+
+    $bytes_in = $i2c->read( $len_in )->get
+
+Performs a complete I²C transaction to receive the given number of bytes back
+from the slave chip. This includes the start condition, sending the addressing
+byte and ending in a stop condition.
+
 =head2 write_then_read
 
     $bytes_in = $i2c->write_then_read( $bytes_out, $len_in )->get
